CommandOutput

Trait CommandOutput 

pub trait CommandOutput {
    type R;

    // Required method
    fn result(output: &Output) -> Result<Self::R>;
}
Parse and decode the output of Kitty’s remote commands.

For some commands the output, CommandOutput::R is just (), for some commands it’s actual data like OsWindows for the Ls command.

Required Associated Types

type R

The decoded output’s type

Required Methods

fn result(output: &Output) -> Result<Self::R>

Handle the exit status, and parse/decode the standard output

Errors

Returns an error when the output contains a non-zero exit code or the ouput cannot be decoded

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors